# -*- coding: utf-8 -*-
from setuphelpers import *
import requests

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

UninstallKey                           Software                                                              Version             Uninstallstring
-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
fbd30ee5-8150-549e-9aed-fd9d444364fb   XMind 11.1.2                                                          11.1.2              "C:\Program Files\XMind\Uninstall XMind.exe" /allusers
XMind_is1                              XMind 8 Update 9 (v3.7.9)                                             3.7.9.201912052356  "C:\Program Files (x86)\XMind\unins000.exe"

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
bin_contains = "XMind-for-Windows-"
silentflags = "/allusers /S"
app_uninstallkey = "fbd30ee5-8150-549e-9aed-fd9d444364fb"


def install():
    # Declaring local variables
    package_version = control.get_software_version()
    bin_name = glob.glob("*%s*.exe" % bin_contains)[0]

    # Installing the software
    print("Installing: %s" % bin_name)
    install_exe_if_needed(
        bin_name,
        silentflags=silentflags,
        key=app_uninstallkey,
        min_version=package_version,
    )


def update_package():
    # Declaring local variables
    result = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name
    if control.architecture == "x64":
        url = "https://www.xmind.net/zen/download/win64/"
        arch = "64bit"
    else:
        url = "https://www.xmind.net/zen/download/win32/"
        arch = "32bit"

    # Getting latest version from official sources
    print("URL used is: %s" % url)

    download_url = requests.head(url, proxies=proxies, allow_redirects=True).url
    version = download_url.split("/")[-1].split("-")[-2]
    latest_bin = download_url.split("/")[-1]
    end_bin_name = download_url.split("-")[-1]

    print("Latest %s version is: %s" % (app_name, version))
    print("Download URL is: %s" % download_url)

    # Downloading latest binaries
    if not isfile(latest_bin):
        print("Downloading: %s" % latest_bin)
        wget(download_url, latest_bin, proxies=proxies)

        # Checking version from file
        version_from_file = get_version_from_binary(latest_bin)
        # if not version_from_file.startswith(version) and version_from_file != '':
        if Version(version_from_file) != Version(version) and version_from_file != "":
            print("Changing version to the version number of the binary (from: %s to: %s)" % (version, version_from_file))
            os.rename(latest_bin, bin_contains + arch + "-" + version_from_file + "-" + end_bin_name)
            version = version_from_file
        else:
            print("Binary file version corresponds to online version")

    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        result = True
    else:
        print("Software version up-to-date (%s)" % Version(version))
    control.version = "%s-%s" % (Version(version), control.version.split("-", 1)[-1])
    # control.set_software_version(version)
    control.save_control_to_wapt()

    # Deleting outdated binaries
    remove_outdated_binaries(version)

    # Validating or not update-package-sources
    return result
